.. _evariste:

Usage
=====

Here are the command line options for `evariste`.
Note that other tools are installed together `evariste`: :ref:`evs`.

.. argparse::
    :module: evariste.evs.compile.options
    :func: commandline_parser
    :prog: evariste
